.. _apps-wsgi:

=================
WSGI Servers
=================

.. automodule:: pulsar.apps.wsgi


API
=========

WSGIApplication
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: WSGIServer
   :members:
   :member-order: bysource
   
   
WsgiHandler
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: WsgiHandler
   :members:
   :member-order: bysource
   

WsgiResponse
~~~~~~~~~~~~~~~~~~~~~

.. autoclass:: WsgiResponse
   :members:
   :member-order: bysource